    const char *R_VARS[] = {
        "R_ARCH","",
        "R_BROWSER","xdg-open",
        "R_BZIPCMD","/bin/bzip2",
        "R_CMD","/usr/lib/R/bin/Rcmd",
        "R_DEFAULT_PACKAGES","",
        "R_DOC_DIR","/usr/share/R/doc",
        "R_GZIPCMD","/bin/gzip",
        "R_HOME","/usr/lib/R",
        "R_INCLUDE_DIR","/usr/share/R/include",
        "R_INSTALL_PKG","RInside",
        "R_LIBRARY_DIR","/home/edd/svn/rinside/pkg.Rcheck",
        "R_LIBS","/home/edd/svn/rinside/pkg.Rcheck:/home/edd/svn/rinside/pkg.Rcheck",
        "R_LIBS_SITE","/usr/local/lib/R/site-library:/usr/lib/R/site-library:/usr/lib/R/library",
        "R_LIBS_USER","~/R/x86_64-pc-linux-gnu-library/2.14",
        "R_OSTYPE","unix",
        "R_PACKAGE_DIR","/home/edd/svn/rinside/pkg.Rcheck/RInside",
        "R_PACKAGE_NAME","RInside",
        "R_PAPERSIZE","letter",
        "R_PAPERSIZE_USER","letter",
        "R_PDFVIEWER","/usr/bin/xdg-open",
        "R_PLATFORM","x86_64-pc-linux-gnu",
        "R_PRINTCMD","/usr/bin/lpr",
        "R_RD4DVI","ae",
        "R_RD4PDF","times,inconsolata,hyper",
        "R_SHARE_DIR","/usr/share/R/share",
        "R_SYSTEM_ABI","linux,gcc,gxx,gfortran,?",
        "R_TEXI2DVICMD","/usr/bin/texi2dvi",
        "R_UNZIPCMD","/usr/bin/unzip",
        "R_VERSION","2.14.0",
        "R_ZIPCMD","/usr/bin/zip",
        NULL
    };
